==> ibiz-runtime-8.1.0.286-sources.jar: net/ibizsys/central/Version.java <==
package net.ibizsys.central;

/**
 *
 * 8.1.0.286.230402
 * 
 * 修复
 * (1) 阶段提交，CloudDevOps增强代码发布等
 * (2) 修复模型临时文件前缀过短问题
 * 
 * 
 * 8.1.0.285.230324
 * 
 * 增加
 * (1) 合入模型包最新代码
 * (2) 属性值转换增强
 * (3) 属性类型二进制流支持
 * 
 * 修复
 * (1) 修复DSL导出包多项导出问题
 * (2) 修复流程部署多流程实体安装异常问题
 * (3) 修复继承实体填充完整信息
 * 
 * 8.1.0.284.230309
 * 
 * 增加
 * (1) 合入模型包最新代码
 * 
 * 修复
 * (1) 修复虚拟实体索引模式主实体持久化对象计算
 * (2) 修复虚拟实体索引模式排除多继承关系处理
 * 
 * 
 * * 8.1.0.282.230307
 * 
 * 增加
 * (1) 合入模型包最新代码
 * (2) 新增流程取消状态与取消流程后回调兼容原配置
 * 
 * 修复
 * (1) 修复流程获取用户时dcsystemid获取问题，解决通过管理端做流程跳转时错误的获取了当前系统的dcsystem
 * (2) 修复流程回退与流程撤回activedate获取异常问题
 * 
 * 
 * * 8.1.0.281.230222
 * 
 * 增加
 * (1) 合入调整规则引擎核心及DSL相关代码
 * 
 * 修复
 * (1) 修复通过流程步骤跳转导致待办归属系统标识异常，不使用流程实例中的dcsystemid
 * (2) 修复文件上传过滤获取配置空指针异常
 * 
 * 8.1.0.280.230221
 * 
 * 增加
 * (1) 合入模型包相关代码，导出项是否隐藏，面板部件项值属性等代码等
 * (2) 数据集支持返回嵌套数据
 * (3) 优化Groovy后台插件加载机制
 * (4) 工作流识别结束节点退出切换状态属性设置
 * (5) 文件上传组件新增后缀过滤配置
 * 
 * 修复
 * (1) 修复通过流程步骤跳转导致待办归属系统标识异常
 * 
 * 8.1.0.279.230213
 * 
 * 增加
 * (1) 合入模型包相关代码，增强DTO属性值格式化、界面行为组成员附加内容等
 * (2) 合入CentralStudio相关代码
 * (3) 优化处理逻辑相关代码等
 * 
 * 修复
 * (1) 修复Cloud任务启动时未准备已启动任务
 * (2) 修复工作流草稿数据重定向计算数据缺失
 * (3) 调整工作流草稿流程代码标识匹配大小写忽略
 * 
 *
 * 8.1.0.278.230201
 * 
 * 增加
 * (1) 模型接口包合入行为规则相关对象
 * (2) 模型包合入数据编辑器等
 * (3) DTO基本数组属性类型支持
 * 
 * 
 * 8.1.0.276.230116
 * 
 * 增加
 * (1) 合入模型包相关代码，增强编辑器项及表单多项数据部件等
 * 
 * 修复
 * (1) 补充工作流启动执行日志输出
 * (2) 工作流注册增强将流程代码标识填入，流程重定向补充对草稿数据的重定向跳转
 * 
 * 8.1.0.275.230112
 * 
 * 修复
 * (1) 工作启动增强，识别流程代码标识后台启动
 * 
 *
 * 8.1.0.274.230111
 * 
 * 增加 
 * (1) 新增 RSA 值转换器
 * (2) 增强 Cloud邮件通知
 * (3) 补充用户密码初始化与修改时写入密码变更时间
 * 
  *   修复
 * (1) 获取待办路径时避免空值异常
 *  
 *  
 * 8.1.0.272.230110
 * 
 *  增加 
 * (1) 调整TODO跳转路径新旧模式兼容问题
 * (2) 合入模型包相关代码
 * (3) 增强CentralStudio包，MeterSphere 初始化测试项目完成
 *  
 *   修复
 * (1) 修复工作流已办通知发送及处理时间，子流程多实例识别出流程连线条件
 * 
 * 
 * 8.1.0.271.230109
 * 
 *  增加 
 * (1) 增加后台插件重新加载功能
 * (2) 增加Groovy插件上下文能力，支持直接获取配置、参数等
 * (3) 合入centralstudio-metersphere包
 *  
 *   修复
 * (1) 子流程工作流实例操作调整结束流程事件时标识合成数据
 * 
 * 8.1.0.270.230106
 * 
 *   修复
 * (1) 优化后台启动工作流时应用标识不存在时历史操作加载及待办跳转异常问题
 * 
 * 
 * 8.1.0.269.230106
 * 
  *  增加 
 * (1) CentralStudio 包合入插件等代码
 * (2) 工作流增强:涉及子流程多实例注册、待办跳转参数识别、活动调用辅助获取流程定义辅助方法
 * 
 * 
 * 8.1.0.268.230104
 * 
  *  增加 
 * (1) 识别查询中无值忽略类动态sql解析
 * (2) CentralStudio服务包增强
 * 
 * 修复
 * (1) 优化后台启动工作流时应用标识不存在时历史操作加载及待办跳转异常问题
 *  
 * 8.1.0.267.221228
 * 
  *  增加 
 * (1) 合入iBizCloudCore模型，应用增加工作流清单属性
 * (2) CloudDevOps部署时登记应用工作流信息
 * 
 * 8.1.0.266.221223
 * 
  *  增加 
 * (1) 新增工作量子流程相关适配
 * (2) 合入centralstudio-groovy包
 * 
 *  8.1.0.265.221222
 * 
  * 增加 
 * (1) 增强模型包，合入嵌入流程多实例，子应用等代码
 * (2) CloudDevOps组件增强子应用配置输出
 * 
 * 修复
 * (1) 修复流程注册与启动时主信息属性类型非String时类型转化错误
 * (2) 修复Cloud RememberMe 用户信息不存在失效的问题等
 * 
 * 8.1.0.263.221219
 * 
  * 增加 
 * (1) 强化部署系统变化检查等

 * 
 *8.1.0.262.221219
 * 
  * 增加 
 * (1) 增强模型包，合入子应用引用模型等
 * (2) CloudDevOps组件支持应用总线配置获取等
 * (3) 增加Cloud全局插件服务等
 * (4) CloudAuth组件增加Http认证代理等
 * 
  * 修复
 * 
 * 
 * 8.1.0.261.221215
 * 
 * 增加 
 * (1) CloudDevOps组件增强热代码应用等
 * 
 * 修复
 * (1) 修复数值字段IN|NOTIN查询条件转化时出现异常
 * (2) 修复虚拟多继承实体的数据源问题等
 * 
 *  * 8.1.0.259.221214
 *  
 * 8.1.0.258.221214
  *  增加
 * (1)  Cloud DevOps组件增强
 * 
 *  * 8.1.0.257.221213
 * 增加
 * (1) 增强接口文档输出能力
 * (2) 增强Groovy运行时插件能力等
 * (3) 关闭R8Gateway接口等
 * (4) 内容应用及系统资源等初步提供
 * (5) 合入RuntimeLite，Gateway等组件
 * (6) 代理应用功能初步提供
 * (7) 优化系统启动工作流，添加默认获取最新流程定义标识
 * (8) 增强CloudDevOps组件系统（调试系统）执行能力
 * 
 * 8.1.0.256.221202
 * 增加
 * (1) 增加本地服务接口插件
 * 
 * 8.1.0.255.221202
 * 增加
 * (1) 增强Groovy代码注解处理
 * 
 * 8.1.0.254.221130
 * 增加
 * (1) 增强Groovy插件相关能力，初步提供autowire等机制方便用户简单编写代码
 * (2) 合入Python组件，增加本地Python服务接口
 * (3) 增强DevOps组件等，为Cloud调试器提供数据支持
 * (4) 合入模型包等相关代码
 * (5) 工作流流程跳转、流程取消接口加入权限判断，工作流回调补充报错信息优化
 *  
 * 
 * 8.1.0.253.221124
 *  
 * 修复
 * (1) 修复中台模式下wfrollback默认传递
 * 
 *  8.1.0.252.221124
 *  
 * 修复
 * (1) 修复热部署关闭全局线程池的问题
 * (2) 合入模型包代码
 * 
 * 
 * 8.1.0.250.221123
 *  
 * 修复
 * (1) 工作流事务回滚增强、流程结束回调清空步骤值
 * 
 * 8.1.0.249.221123
 *  
 * 修复
 * (1) 修复热部署接口文档更新问题
 * 
 * 8.1.0.248.221123
  *  增加
 * (1) Cloud门户组件标记打开数据功能基本提供
 * (2) 合入CloudRabbitMQ项目等
 * (3) 合入门户异步作业相关代码
 * (4) 支持后台系统热刷新
 * (5) 合入模型包代码
 * 
 *   修复
 * (1) 修复机构用户系统管理员计算
 * 
 * 
 * 8.1.0.245.221118
 * 增加
 * (1) 合入模型包代码
 * 
 * 修复
 * (1) 修复getAppData机构管理员没有关闭界面权限控制的问题
 * 
 * 8.1.0.244.221115
 * 增加
 * (1) 合入ES大数据库代码，ES大数据存储功能基本提供
 * (2) 后台插件支持静态组件和动态组件自适应等
 * (3) 模型工具基类代码优化
 * (4) 合入模型包代码
 * 
 * 8.1.0.243.221110
 * 增加
 * (1) 修复CloudWF组件反馈流程图
 * (2) 工作流支持回滚回调操作
 * 
 *  * 8.1.0.242.221109
 * 增加
 * (1) 合入ActiveMQ数据同步代理相关代码
 * (2) 工作流事务回滚增强
 * (3) 增强后台扩展插件功能
 * (4) 合入外部服务接口方法插件相关代码
 * (5) 合入模型包代码
 * 
 * 8.1.0.241.221107
 * 增加
 * (1) 细化实体数据同步输出逻辑
 * (2) 模型包升级，后台运行时插件输出运行时代码
 * (3) 支持Groovy运行时插件
 * (4) 优化注册运行时组件相关代码
 * 
 * 8.1.0.240.221104
 * 增加
 * (1) 优化数据同步处理，RabbitMQ基本功能提供
 * (2) 修复通知组件未注册Leadership的问题
 * (3) 合入CloudCore模型
 * 
 * 修复
 * (1) 修复实体导入中时间日期列格式在重构错误Excel单元格过程中错误的获取方式导致中断跳出问题
 * 
 * 
 * 8.1.0.239.221104
 * 修复
 * (1) 修复数据同步重复调用的问题
 * 
 * 8.1.0.238.221103
 * 增加
 * (1) 合入CloudCore模型
 * 
 *  * 8.1.0.237.221103
 * 增加
 * (1) 大数据体系等相关代码调整，Solr基本功能实现
 * (2) 数据同步体系相关代码调整，RabbitMQ发送功能提供
 * (3) 合入CloudCore模型
 * 
 * 
 * 8.1.0.236.221027
 * 增加
 * (1) 大数据体系代码优化
 * (2) 合入模型包相关代码
 * (3) 初始化RabbitMQ等项目
 * 
 * 修复
 * (1) 修复DataEntityRuntimeBase#getSetting没有执行prepare的问题
 * 
 * 8.1.0.235.221026
 * 增加
 * (1) DevOps支持获取未认证用户的简单模型
 * 
 * 8.1.0.234.221025
 * 修复
 * (1) 修复实体导入数据格式错误识别失败中断跳出问题
 * 
 * 8.1.0.233.221020
 * 修复
 * (1) 修复带实体对象参数的外部服务接口调用使用数据键名不一致的问题
 * 
 * 8.1.0.232.221018
 * 修复
 * (1) 修复外部服务接口调用使用数据键名不一致的问题
 * 
 * 
 * 8.1.0.231.221018
 * 增加
 * (1) 工作流服务回调使用Cloud链路，SystemRuntime处理由相应的调整，此升级需要同时升级Cloud侧和系统侧
 * 
 * 8.1.0.230.221014
 * 增加
 * (1) centralstudio 去掉对runtime包依赖，相关代码调整
 * (2) net.ibizsys.central.cloud.core.dataentity.wf.DEWFRuntime 增强Cloud实体的回调处理
 * 
 * 修复
 * (1) 修复用户上下文仿真  uaausername 及 personname 混淆问题
 * (2) 修复 net.ibizsys.central.cloud.workflow.flowable.util.WFCoreService 回调实体服务时未传入默认主键(srfkey)的问题 
 * 
 * 
 * 8.1.0.225
 * 增加
 * 
 * 修复
 * (1) net.ibizsys.central.cloud.core.ServiceSystemRuntime 设置默认系统文件功能组件为服务总线的默认OSS功能组件
 * 
 * 运行时版本
 * @author lionlau
 *
 */
public class Version {


	public final static Integer MAJOR = 8;
	public final static Integer MINOR = 1;
	public final static Integer FUNC = 0;
	public final static Integer FIX = 286;
	public final static Integer DATE = 230402;
	
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString()
	{
		return String.format("%1$s.%2$s.%3$s.%4$s",MAJOR,MINOR,FUNC,FIX);
	}
	
	/**
	 * 输出版本字符串
	 * @return
	 */
	public static String toVersionString()
	{
		return String.format("%1$s.%2$s.%3$s.%4$s",MAJOR,MINOR,FUNC,FIX);
	}

}

==> ibiz-runtime-8.1.0.298-sources.jar: net/ibizsys/central/Version.java <==
package net.ibizsys.central;

/**
 * 
 *  * 8.1.0.298.230531
 *
 *修复
 * (1) 修复由于clone数据丢失信息还原流程步骤获取原对象操作，调整历史步骤名称附加逻辑避免重复附加
 * 
 * 
 * *  8.1.0.296.230531
 * 
 * 增加
 * (1) 增加CloudAI组件能力
 * 
 *  8.1.0.295.230529
 * 
 * 增加
 * (1) Cloud-Auth增强密码策略
 * 
 * 8.1.0.294.230529
 * 
 * 增加
 * (1) 合入 cloud-ai 组件
 *
 *修复
 * (1) 修复引入Mybatis动态sql解析后自定义查询出现异常
 * (2) 修复流程多次撤回导致撤回步骤计算异常与审批人数计算异常导致无法撤回
 * 
 * 8.1.0.293.230526
 * 
 * 增加
 * (1) 数据库体系支持配置实际数据库类型
 * 
 * 
 * 8.1.0.291.230526
 * 
 * 增加
 * (1) 批插入、批更新只执行一次SQL ibiz.db.batchmode=SINGLESQL
 * (2) 修复实体保存（SAVE）列表入参不识别的问题
 * (3) 查询Map对象返回key转大写
 * 
 * 8.1.0.290.230525
 * 
 * 增加
 * (1) 合入模型包最新代码
 * (2) CloudOSS提供对象存储，Cloud服务系统默认支持对象存储
 * (3) 实体行为附加逻辑支持插件、目标数据操作等
 * (4) 嵌套数据处理支持排序属性逻辑
 * (5) 逻辑节点参数支持值转换处理
 * (6) 处理逻辑增强，直接SQL调用支持返回支持填充列表
 * (7) 处理逻辑增强，直接SQL调用增强数据库体系为空判断
 * (8) ServiceHub支持线程池配置
 * (9) 支持实体处理逻辑循环子调用等
 * 
 * 
 * 修复
 * (1) 修复流程附加历史版本标记时错误的操作了原对象导致重复附加
 * (2) 修复数据库多源问题
 * 
 * 
 * 
 * * * 8.1.0.289.230514
 * 
 *  增加
 * (1) 合入模型包最新代码
 * 
 * 
 * * 8.1.0.288.230514
 * 
 * 增加
 * (1) 合入模型包最新代码
 * (2) 实体映射处理支持映射模式（默认和内部）
 * 
 * 调整
 * (1) 调整实体服务接口应用上下文设置位置
 * (2) 定时器执行异常本地截获（原来抛出）
 * 
 * 修复
 * (1) 优化日志处理计时器多线程模式
 * 
 * 8.1.0.287.230419
 * 
 * 增加
 * (1) 合入模型包最新代码
 * (2) 支持Exists，NotExists 条件支持
 * 
 *  修复
 * (1) 修复引入Mybatis动态sql解析后导致内存泄露问题
 * 
 * 8.1.0.286.230402
 * 
 * 修复
 * (1) 阶段提交，CloudDevOps增强代码发布等
 * (2) 修复模型临时文件前缀过短问题
 * 
 * 
 * 8.1.0.285.230324
 * 
 * 增加
 * (1) 合入模型包最新代码
 * (2) 属性值转换增强
 * (3) 属性类型二进制流支持
 * 
 * 修复
 * (1) 修复DSL导出包多项导出问题
 * (2) 修复流程部署多流程实体安装异常问题
 * (3) 修复继承实体填充完整信息
 * 
 * 8.1.0.284.230309
 * 
 * 增加
 * (1) 合入模型包最新代码
 * 
 * 修复
 * (1) 修复虚拟实体索引模式主实体持久化对象计算
 * (2) 修复虚拟实体索引模式排除多继承关系处理
 * 
 * 
 * * 8.1.0.282.230307
 * 
 * 增加
 * (1) 合入模型包最新代码
 * (2) 新增流程取消状态与取消流程后回调兼容原配置
 * 
 * 修复
 * (1) 修复流程获取用户时dcsystemid获取问题，解决通过管理端做流程跳转时错误的获取了当前系统的dcsystem
 * (2) 修复流程回退与流程撤回activedate获取异常问题
 * 
 * 
 * * 8.1.0.281.230222
 * 
 * 增加
 * (1) 合入调整规则引擎核心及DSL相关代码
 * 
 * 修复
 * (1) 修复通过流程步骤跳转导致待办归属系统标识异常，不使用流程实例中的dcsystemid
 * (2) 修复文件上传过滤获取配置空指针异常
 * 
 * 8.1.0.280.230221
 * 
 * 增加
 * (1) 合入模型包相关代码，导出项是否隐藏，面板部件项值属性等代码等
 * (2) 数据集支持返回嵌套数据
 * (3) 优化Groovy后台插件加载机制
 * (4) 工作流识别结束节点退出切换状态属性设置
 * (5) 文件上传组件新增后缀过滤配置
 * 
 * 修复
 * (1) 修复通过流程步骤跳转导致待办归属系统标识异常
 * 
 * 8.1.0.279.230213
 * 
 * 增加
 * (1) 合入模型包相关代码，增强DTO属性值格式化、界面行为组成员附加内容等
 * (2) 合入CentralStudio相关代码
 * (3) 优化处理逻辑相关代码等
 * 
 * 修复
 * (1) 修复Cloud任务启动时未准备已启动任务
 * (2) 修复工作流草稿数据重定向计算数据缺失
 * (3) 调整工作流草稿流程代码标识匹配大小写忽略
 * 
 *
 * 8.1.0.278.230201
 * 
 * 增加
 * (1) 模型接口包合入行为规则相关对象
 * (2) 模型包合入数据编辑器等
 * (3) DTO基本数组属性类型支持
 * 
 * 
 * 8.1.0.276.230116
 * 
 * 增加
 * (1) 合入模型包相关代码，增强编辑器项及表单多项数据部件等
 * 
 * 修复
 * (1) 补充工作流启动执行日志输出
 * (2) 工作流注册增强将流程代码标识填入，流程重定向补充对草稿数据的重定向跳转
 * 
 * 8.1.0.275.230112
 * 
 * 修复
 * (1) 工作启动增强，识别流程代码标识后台启动
 * 
 *
 * 8.1.0.274.230111
 * 
 * 增加 
 * (1) 新增 RSA 值转换器
 * (2) 增强 Cloud邮件通知
 * (3) 补充用户密码初始化与修改时写入密码变更时间
 * 
  *   修复
 * (1) 获取待办路径时避免空值异常
 *  
 *  
 * 8.1.0.272.230110
 * 
 *  增加 
 * (1) 调整TODO跳转路径新旧模式兼容问题
 * (2) 合入模型包相关代码
 * (3) 增强CentralStudio包，MeterSphere 初始化测试项目完成
 *  
 *   修复
 * (1) 修复工作流已办通知发送及处理时间，子流程多实例识别出流程连线条件
 * 
 * 
 * 8.1.0.271.230109
 * 
 *  增加 
 * (1) 增加后台插件重新加载功能
 * (2) 增加Groovy插件上下文能力，支持直接获取配置、参数等
 * (3) 合入centralstudio-metersphere包
 *  
 *   修复
 * (1) 子流程工作流实例操作调整结束流程事件时标识合成数据
 * 
 * 8.1.0.270.230106
 * 
 *   修复
 * (1) 优化后台启动工作流时应用标识不存在时历史操作加载及待办跳转异常问题
 * 
 * 
 * 8.1.0.269.230106
 * 
  *  增加 
 * (1) CentralStudio 包合入插件等代码
 * (2) 工作流增强:涉及子流程多实例注册、待办跳转参数识别、活动调用辅助获取流程定义辅助方法
 * 
 * 
 * 8.1.0.268.230104
 * 
  *  增加 
 * (1) 识别查询中无值忽略类动态sql解析
 * (2) CentralStudio服务包增强
 * 
 * 修复
 * (1) 优化后台启动工作流时应用标识不存在时历史操作加载及待办跳转异常问题
 *  
 * 8.1.0.267.221228
 * 
  *  增加 
 * (1) 合入iBizCloudCore模型，应用增加工作流清单属性
 * (2) CloudDevOps部署时登记应用工作流信息
 * 
 * 8.1.0.266.221223
 * 
  *  增加 
 * (1) 新增工作量子流程相关适配
 * (2) 合入centralstudio-groovy包
 * 
 *  8.1.0.265.221222
 * 
  * 增加 
 * (1) 增强模型包，合入嵌入流程多实例，子应用等代码
 * (2) CloudDevOps组件增强子应用配置输出
 * 
 * 修复
 * (1) 修复流程注册与启动时主信息属性类型非String时类型转化错误
 * (2) 修复Cloud RememberMe 用户信息不存在失效的问题等
 * 
 * 8.1.0.263.221219
 * 
  * 增加 
 * (1) 强化部署系统变化检查等

 * 
 *8.1.0.262.221219
 * 
  * 增加 
 * (1) 增强模型包，合入子应用引用模型等
 * (2) CloudDevOps组件支持应用总线配置获取等
 * (3) 增加Cloud全局插件服务等
 * (4) CloudAuth组件增加Http认证代理等
 * 
  * 修复
 * 
 * 
 * 8.1.0.261.221215
 * 
 * 增加 
 * (1) CloudDevOps组件增强热代码应用等
 * 
 * 修复
 * (1) 修复数值字段IN|NOTIN查询条件转化时出现异常
 * (2) 修复虚拟多继承实体的数据源问题等
 * 
 *  * 8.1.0.259.221214
 *  
 * 8.1.0.258.221214
  *  增加
 * (1)  Cloud DevOps组件增强
 * 
 *  * 8.1.0.257.221213
 * 增加
 * (1) 增强接口文档输出能力
 * (2) 增强Groovy运行时插件能力等
 * (3) 关闭R8Gateway接口等
 * (4) 内容应用及系统资源等初步提供
 * (5) 合入RuntimeLite，Gateway等组件
 * (6) 代理应用功能初步提供
 * (7) 优化系统启动工作流，添加默认获取最新流程定义标识
 * (8) 增强CloudDevOps组件系统（调试系统）执行能力
 * 
 * 8.1.0.256.221202
 * 增加
 * (1) 增加本地服务接口插件
 * 
 * 8.1.0.255.221202
 * 增加
 * (1) 增强Groovy代码注解处理
 * 
 * 8.1.0.254.221130
 * 增加
 * (1) 增强Groovy插件相关能力，初步提供autowire等机制方便用户简单编写代码
 * (2) 合入Python组件，增加本地Python服务接口
 * (3) 增强DevOps组件等，为Cloud调试器提供数据支持
 * (4) 合入模型包等相关代码
 * (5) 工作流流程跳转、流程取消接口加入权限判断，工作流回调补充报错信息优化
 *  
 * 
 * 8.1.0.253.221124
 *  
 * 修复
 * (1) 修复中台模式下wfrollback默认传递
 * 
 *  8.1.0.252.221124
 *  
 * 修复
 * (1) 修复热部署关闭全局线程池的问题
 * (2) 合入模型包代码
 * 
 * 
 * 8.1.0.250.221123
 *  
 * 修复
 * (1) 工作流事务回滚增强、流程结束回调清空步骤值
 * 
 * 8.1.0.249.221123
 *  
 * 修复
 * (1) 修复热部署接口文档更新问题
 * 
 * 8.1.0.248.221123
  *  增加
 * (1) Cloud门户组件标记打开数据功能基本提供
 * (2) 合入CloudRabbitMQ项目等
 * (3) 合入门户异步作业相关代码
 * (4) 支持后台系统热刷新
 * (5) 合入模型包代码
 * 
 *   修复
 * (1) 修复机构用户系统管理员计算
 * 
 * 
 * 8.1.0.245.221118
 * 增加
 * (1) 合入模型包代码
 * 
 * 修复
 * (1) 修复getAppData机构管理员没有关闭界面权限控制的问题
 * 
 * 8.1.0.244.221115
 * 增加
 * (1) 合入ES大数据库代码，ES大数据存储功能基本提供
 * (2) 后台插件支持静态组件和动态组件自适应等
 * (3) 模型工具基类代码优化
 * (4) 合入模型包代码
 * 
 * 8.1.0.243.221110
 * 增加
 * (1) 修复CloudWF组件反馈流程图
 * (2) 工作流支持回滚回调操作
 * 
 *  * 8.1.0.242.221109
 * 增加
 * (1) 合入ActiveMQ数据同步代理相关代码
 * (2) 工作流事务回滚增强
 * (3) 增强后台扩展插件功能
 * (4) 合入外部服务接口方法插件相关代码
 * (5) 合入模型包代码
 * 
 * 8.1.0.241.221107
 * 增加
 * (1) 细化实体数据同步输出逻辑
 * (2) 模型包升级，后台运行时插件输出运行时代码
 * (3) 支持Groovy运行时插件
 * (4) 优化注册运行时组件相关代码
 * 
 * 8.1.0.240.221104
 * 增加
 * (1) 优化数据同步处理，RabbitMQ基本功能提供
 * (2) 修复通知组件未注册Leadership的问题
 * (3) 合入CloudCore模型
 * 
 * 修复
 * (1) 修复实体导入中时间日期列格式在重构错误Excel单元格过程中错误的获取方式导致中断跳出问题
 * 
 * 
 * 8.1.0.239.221104
 * 修复
 * (1) 修复数据同步重复调用的问题
 * 
 * 8.1.0.238.221103
 * 增加
 * (1) 合入CloudCore模型
 * 
 *  * 8.1.0.237.221103
 * 增加
 * (1) 大数据体系等相关代码调整，Solr基本功能实现
 * (2) 数据同步体系相关代码调整，RabbitMQ发送功能提供
 * (3) 合入CloudCore模型
 * 
 * 
 * 8.1.0.236.221027
 * 增加
 * (1) 大数据体系代码优化
 * (2) 合入模型包相关代码
 * (3) 初始化RabbitMQ等项目
 * 
 * 修复
 * (1) 修复DataEntityRuntimeBase#getSetting没有执行prepare的问题
 * 
 * 8.1.0.235.221026
 * 增加
 * (1) DevOps支持获取未认证用户的简单模型
 * 
 * 8.1.0.234.221025
 * 修复
 * (1) 修复实体导入数据格式错误识别失败中断跳出问题
 * 
 * 8.1.0.233.221020
 * 修复
 * (1) 修复带实体对象参数的外部服务接口调用使用数据键名不一致的问题
 * 
 * 8.1.0.232.221018
 * 修复
 * (1) 修复外部服务接口调用使用数据键名不一致的问题
 * 
 * 
 * 8.1.0.231.221018
 * 增加
 * (1) 工作流服务回调使用Cloud链路，SystemRuntime处理由相应的调整，此升级需要同时升级Cloud侧和系统侧
 * 
 * 8.1.0.230.221014
 * 增加
 * (1) centralstudio 去掉对runtime包依赖，相关代码调整
 * (2) net.ibizsys.central.cloud.core.dataentity.wf.DEWFRuntime 增强Cloud实体的回调处理
 * 
 * 修复
 * (1) 修复用户上下文仿真  uaausername 及 personname 混淆问题
 * (2) 修复 net.ibizsys.central.cloud.workflow.flowable.util.WFCoreService 回调实体服务时未传入默认主键(srfkey)的问题 
 * 
 * 
 * 8.1.0.225
 * 增加
 * 
 * 修复
 * (1) net.ibizsys.central.cloud.core.ServiceSystemRuntime 设置默认系统文件功能组件为服务总线的默认OSS功能组件
 * 
 * 运行时版本
 * @author lionlau
 *
 */
public class Version {


	public final static Integer MAJOR = 8;
	public final static Integer MINOR = 1;
	public final static Integer FUNC = 0;
	public final static Integer FIX = 298;
	public final static Integer DATE = 230531;
	
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString()
	{
		return String.format("%1$s.%2$s.%3$s.%4$s",MAJOR,MINOR,FUNC,FIX);
	}
	
	/**
	 * 输出版本字符串
	 * @return
	 */
	public static String toVersionString()
	{
		return String.format("%1$s.%2$s.%3$s.%4$s",MAJOR,MINOR,FUNC,FIX);
	}

}
